@@ -22,7 +22,7 @@ import random
 import re
 import string
 import time
-from collections import deque
+from collections import deque, OrderedDict
 
 import requests
 import websocket
@@ -31,7 +31,7 @@ from threading import Barrier, Condition, Thread
 
 from .multipart import Data
 
-__version__ = "0.8.5"
+__version__ = "0.8.9"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -111,7 +111,7 @@ class Connection(requests.Session):
             ws_url, header=["User-Agent: {}".format(agent)])
 
         self.max_id = 0
-        self._send_count = 0
+        self._send_count = 1
 
     @property
     def connected(self):
@@ -224,7 +224,7 @@ class RoomConnection(Connection):
         """Listens for new data about the room from the websocket
         and updates given room state accordingly."""
 
-        barrier = Barrier(2)
+        barrier = Barrier(3)
 
         def listen():
             """Thread: Listen to incoming data"""
@@ -261,6 +261,7 @@ class RoomConnection(Connection):
 
         def ping():
             """Thread: ping the server in intervals"""
+            barrier.wait()
             while self.connected:
                 try:
                     self.send_message('2')
@@ -299,12 +300,18 @@ class Room:
             except Exception as ex:
                 raise IOError("Failed to create room") from ex
 
+        try:
+            text = self.conn.get(BASE_ROOM_URL + self.name).text
+            self.title = re.search(r'name\s*:\s*"(.+?)"', text).group(1)
+        except Exception as ex:
+            raise IOError("Failed to get room title") from ex
+
         self.user = User(user or random_id(5), self.conn)
 
         self.conn.subscribe(self.name, self.user.name)
 
         self._user_count = 0
-        self._files = {}
+        self._files = OrderedDict()
         self._chat_log = []
 
         self.conn.listen_forever(self)
@@ -365,6 +372,10 @@ class Room:
                 chat_message = parse_chat_message(data)
                 self.conn.enqueue_message(chat_message)
                 self._chat_log.append(chat_message)
+            elif data_type == "changed_config":
+                change = item[0][1][1]
+                if change['key'] == 'name':
+                    self.title = change['value']
 
     @property
     def chat_log(self):
@@ -435,7 +446,12 @@ class Room:
         if self.connected:
             self.conn.close()
 
-    def set_room_name(self, new_name):
+    @property
+    def room_title(self):
+        """Gets the title name of the room (e.g. /g/entoomen)"""
+        return self.title
+
+    def set_room_title(self, new_name):
         """Sets the room name"""
         if len(new_name) > 24 or len(new_name) < 1:
             raise ValueError(
